/*----------------------------------------------------------------------
copyright (c) 2008 Georget Fabien

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
--------------------------------------------------------------------------
File : CompDock.cpp
Program : gt2n
Date : 12/07/08
--------------------------------------------------------------------------
Nature : C++ file for the compiler dock
--------------------------------------------------------------------------*/

#include "CompDock.h"
#include <QtGui>
#include "MainWindow.h"


CompDock::CompDock(MainWindow *mainWin):QTextEdit(mainWin)
{
  fenPrincipale = mainWin;
  setReadOnly(true);
  goodCompilation = false;
   //create the nbc process
    nbcPath = "nbc";
    nbcProcess.setStandardOutputFile("outputf");
    nbcProcess.setStandardErrorFile("errorf");
    QObject::connect(&nbcProcess,SIGNAL(finished(int,QProcess::ExitStatus)),this,SLOT(s_printOutput(int,QProcess::ExitStatus)));
}

void CompDock::writeLog(QString toWrite)
{
  moveCursor(QTextCursor::End);
  insertPlainText(toWrite+"\n");
}

void CompDock::writeGoodLog(QString toWrite)
{
  moveCursor(QTextCursor::End);
  setTextColor(Qt::blue);
  insertPlainText(toWrite+"\n");
  
   
}
void CompDock::writeErrorLog(QString toWrite)
{
  moveCursor(QTextCursor::End);
  setTextColor(Qt::red);
  insertPlainText(toWrite+"\n");
}

//compile a file
void CompDock::compile(QFileInfo file)
{
  goodCompilation = false;
  writeGoodLog("-------------------------------");
  writeGoodLog("Next Bytes Code compiler");
  writeGoodLog("Copyright (c) 2006 John Hansen");
  writeGoodLog("-------------------------------");
  nbcProcess.setWorkingDirectory(file.canonicalPath());
  writeLog(tr("Compilation"));
  QString rxeFile = file.completeBaseName()+".rxe";
  QStringList arguments;
  arguments << file.fileName() << "-w+"
	    << "-O="+rxeFile ;
  writeLog(nbcProcess.workingDirectory());
  foreach (QString argum,arguments)
  {
    insertPlainText(argum+" ");
  }
  insertPlainText("\n");
  writeLog(tr("Start compilation"));
  nbcProcess.start(nbcPath,arguments);
  if (!nbcProcess.waitForStarted()){return;}
  if (!nbcProcess.waitForFinished()){return;};
  nbcProcess.close(); //nbc retourne 0 même si erreur !
}

// to print output of nbc
void CompDock::s_printOutput(int exitCode, QProcess::ExitStatus exitStatus )
{

   if (exitStatus==QProcess::NormalExit)
    {
      if(exitCode==0)
      {
	writeGoodLog("Compilation finished");
	writeGoodLog("Exit status : 0");
	goodCompilation = true;
      }
      else
      {
	writeErrorLog("/!\\ Compilation aborted /!\\");
	QFile file("errorf");
	if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
	{ 
	  writeLog("Warning : Failed to read output !");
	}
	writeLog("Errors:");
	QTextStream in(&file);
	while (!in.atEnd()) 
	{
	    QString line = in.readLine();
	    writeLog(line);
	}
	file.close();
	in.reset();
	writeErrorLog("Exit status : 1");
      }
     }
   else
    {
      writeErrorLog("Exit status : 1");
      writeErrorLog("Failed to start compiler");
    }
}

// to clean  build Log
void CompDock::s_cleanLog()
{
  QTextDocument *docVierge = new QTextDocument();
  setDocument(docVierge);
}

// to save log
void CompDock::s_saveLog()
 {
     QString fileName = QFileDialog::getSaveFileName(this, tr("Save Log"),QDir::homePath() );
     if (fileName.isEmpty()) return;

     QFile file(fileName);
     if (!file.open(QFile::WriteOnly | QFile::Text)) {
         QMessageBox::warning(this, tr("NeXTide"),
                              tr("Cannot write file %1:\n%2.")
                              .arg(fileName)
                              .arg(file.errorString()));
         return;
     }

     QTextStream out(&file);
     QApplication::setOverrideCursor(Qt::WaitCursor);
     out << toPlainText();
     QApplication::restoreOverrideCursor();

     return;
 }